/**
 * This file is part of Niowire.
 *
 * Niowire is free software: you can redistribute it and/or modify it under the
 * terms of the Lesser GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * Niowire is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the Lesser GNU General Public License for more
 * details.
 *
 * You should have received a copy of the Lesser GNU General Public License
 * along with Niowire. If not, see <http://www.gnu.org/licenses/>.
 */
package io.niowire;

/**
 * This is the common exception super class for all Niowire exceptions (except
 * runtime exceptions. All exceptions generated by Niowire which go out through
 * the public API will be wrapped in an instance of this class.
 *
 * @author Trent Houliston
 */
public class NiowireException extends Exception
{
	//Serial Version UID
	private static final long serialVersionUID = 1L;

	/**
	 * Default constructor, has no message or cause.
	 */
	public NiowireException()
	{
		super();
	}

	/**
	 * Construct a new NiowireException with the passed message
	 *
	 * @param message the message to attach to this exception
	 */
	public NiowireException(String message)
	{
		super(message);
	}

	/**
	 * Construct a new NiowireException with a message and a cause.
	 *
	 * @param message the message to attach to this exception
	 * @param cause   the cause of this exception
	 */
	public NiowireException(String message, Throwable cause)
	{
		super(message, cause);
	}

	/**
	 * Constructs a new NiowireException with a cause
	 *
	 * @param cause the cause of this exception
	 */
	public NiowireException(Throwable cause)
	{
		super(cause);
	}
}
